package checkpointmanager
import "k8s.io/kubernetes/pkg/kubelet/checkpointmanager"
Index ¶
Types ¶
type Checkpoint ¶
type Checkpoint interface {
MarshalCheckpoint() ([]byte, error)
UnmarshalCheckpoint(blob []byte) error
VerifyChecksum() error
}
Checkpoint provides the process checkpoint data
type CheckpointManager ¶
type CheckpointManager interface {
// CreateCheckpoint persists checkpoint in CheckpointStore. checkpointKey is the key for utilstore to locate checkpoint.
// For file backed utilstore, checkpointKey is the file name to write the checkpoint data.
CreateCheckpoint(checkpointKey string, checkpoint Checkpoint) error
// GetCheckpoint retrieves checkpoint from CheckpointStore.
GetCheckpoint(checkpointKey string, checkpoint Checkpoint) error
// WARNING: RemoveCheckpoint will not return error if checkpoint does not exist.
RemoveCheckpoint(checkpointKey string) error
// ListCheckpoint returns the list of existing checkpoints.
ListCheckpoints() ([]string, error)
}
CheckpointManager provides the interface to manage checkpoint
func NewCheckpointManager ¶
func NewCheckpointManager(checkpointDir string) (CheckpointManager, error)
NewCheckpointManager returns a new instance of a checkpoint manager
Source Files ¶
checkpoint_manager.go
Directories ¶
- Version
- v1.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 9 seconds ago –
Tools for package owners.