package pluginmanager
import "k8s.io/kubernetes/pkg/kubelet/pluginmanager"
Index ¶
Types ¶
type PluginManager ¶
type PluginManager interface {
// Starts the plugin manager and all the asynchronous loops that it controls
Run(ctx context.Context, sourcesReady config.SourcesReady, stopCh <-chan struct{})
// AddHandler adds the given plugin handler for a specific plugin type, which
// will be added to the actual state of world cache so that it can be passed to
// the desired state of world cache in order to be used during plugin
// registration/deregistration
AddHandler(pluginType string, pluginHandler cache.PluginHandler)
}
PluginManager runs a set of asynchronous loops that figure out which plugins need to be registered/deregistered and makes it so.
func NewPluginManager ¶
func NewPluginManager( sockDir string, recorder record.EventRecorder) PluginManager
NewPluginManager returns a new concrete instance implementing the PluginManager interface.
Source Files ¶
plugin_manager.go
Directories ¶
| Path | Synopsis |
|---|---|
| pkg/kubelet/pluginmanager/cache | Package cache implements data structures used by the kubelet plugin manager to keep track of registered plugins. |
| pkg/kubelet/pluginmanager/metrics | |
| pkg/kubelet/pluginmanager/operationexecutor | Package operationexecutor implements interfaces that enable execution of register and unregister operations with a goroutinemap so that more than one operation is never triggered on the same plugin. |
| pkg/kubelet/pluginmanager/pluginwatcher | |
| pkg/kubelet/pluginmanager/pluginwatcher/example_plugin_apis | |
| pkg/kubelet/pluginmanager/pluginwatcher/example_plugin_apis/v1beta1 | |
| pkg/kubelet/pluginmanager/pluginwatcher/example_plugin_apis/v1beta2 | |
| pkg/kubelet/pluginmanager/reconciler | Package reconciler implements interfaces that attempt to reconcile the desired state of the world with the actual state of the world by triggering relevant actions (register/deregister plugins). |
- Version
- v1.35.1 (latest)
- Published
- Feb 10, 2026
- Platform
- linux/amd64
- Imports
- 11 packages
- Last checked
- 2 months ago –
Tools for package owners.