package queue
import "k8s.io/kubernetes/pkg/kubelet/util/queue"
Index ¶
Types ¶
type WorkQueue ¶
type WorkQueue interface {
// GetWork dequeues and returns all ready items.
GetWork() []types.UID
// Enqueue inserts a new item or overwrites an existing item.
Enqueue(item types.UID, delay time.Duration)
}
WorkQueue allows queuing items with a timestamp. An item is considered ready to process if the timestamp has expired.
func NewBasicWorkQueue ¶
NewBasicWorkQueue returns a new basic WorkQueue with the provided clock
Source Files ¶
work_queue.go
- Version
- v1.35.1 (latest)
- Published
- Feb 10, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 2 months ago –
Tools for package owners.