package componentstatus
import "k8s.io/kubernetes/pkg/registry/core/componentstatus"
Package componentstatus provides interfaces and implementation for retrieving cluster component status.
Index ¶
- func ToConditionStatus(s probe.Result) api.ConditionStatus
- type EtcdServer
- type HttpServer
- type REST
- func NewStorage(serverRetriever func() map[string]Server) *REST
- func (r *REST) Destroy()
- func (rs *REST) Get(ctx context.Context, name string, options *metav1.GetOptions) (runtime.Object, error)
- func (rs *REST) GetSingularName() string
- func (rs *REST) List(ctx context.Context, options *metainternalversion.ListOptions) (runtime.Object, error)
- func (*REST) NamespaceScoped() bool
- func (rs *REST) New() runtime.Object
- func (rs *REST) NewList() runtime.Object
- func (r *REST) ShortNames() []string
- type Server
- type ServerStatus
- type ValidatorFn
Functions ¶
func ToConditionStatus ¶
func ToConditionStatus(s probe.Result) api.ConditionStatus
Types ¶
type EtcdServer ¶
type EtcdServer struct {
storagebackend.Config
}
func (*EtcdServer) DoServerCheck ¶
func (server *EtcdServer) DoServerCheck() (probe.Result, string, error)
type HttpServer ¶
type HttpServer struct {
Addr string
Port int
Path string
EnableHTTPS bool
TLSConfig *tls.Config
Validate ValidatorFn
Prober httpprober.Prober
Once sync.Once
}
func (*HttpServer) DoServerCheck ¶
func (server *HttpServer) DoServerCheck() (probe.Result, string, error)
type REST ¶
type REST struct {
GetServersToValidate func() map[string]Server
rest.TableConvertor
}
func NewStorage ¶
NewStorage returns a new REST.
func (*REST) Destroy ¶
func (r *REST) Destroy()
Destroy cleans up resources on shutdown.
func (*REST) Get ¶
func (rs *REST) Get(ctx context.Context, name string, options *metav1.GetOptions) (runtime.Object, error)
func (*REST) GetSingularName ¶
func (*REST) List ¶
func (rs *REST) List(ctx context.Context, options *metainternalversion.ListOptions) (runtime.Object, error)
Returns the list of component status. Note that the label and field are both ignored. Note that this call doesn't support labels or selectors.
func (*REST) NamespaceScoped ¶
func (*REST) New ¶
func (*REST) NewList ¶
func (*REST) ShortNames ¶
ShortNames implements the ShortNamesProvider interface. Returns a list of short names for a resource.
type Server ¶
type ServerStatus ¶
type ServerStatus struct {
// +optional
Component string `json:"component,omitempty"`
// +optional
Health string `json:"health,omitempty"`
// +optional
HealthCode probe.Result `json:"healthCode,omitempty"`
// +optional
Msg string `json:"msg,omitempty"`
// +optional
Err string `json:"err,omitempty"`
}
type ValidatorFn ¶
Source Files ¶
doc.go rest.go validator.go
- Version
- v1.35.1 (latest)
- Published
- Feb 10, 2026
- Platform
- linux/amd64
- Imports
- 23 packages
- Last checked
- 2 months ago –
Tools for package owners.