package rangeallocation
import "k8s.io/kubernetes/pkg/registry/core/rangeallocation"
Package rangeallocation provides the Registry interface for storing RangeAllocation api objects.
Index ¶
Types ¶
type RangeRegistry ¶
type RangeRegistry interface {
// Get returns the latest allocation, an empty object if no allocation has been made,
// or an error if the allocation could not be retrieved.
Get() (*api.RangeAllocation, error)
// CreateOrUpdate should create or update the provide allocation, unless a conflict
// has occurred since the item was last created.
CreateOrUpdate(*api.RangeAllocation) error
}
RangeRegistry is a registry that can retrieve or persist a RangeAllocation object.
Source Files ¶
doc.go registry.go
- Version
- v1.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 39 minutes ago –
Tools for package owners.