Affected by GO-2022-0617
and 25 other vulnerabilities
GO-2022-0617 : WITHDRAWN: Potential proxy IP restriction bypass in Kubernetes in k8s.io/kubernetes
GO-2022-0703 : XML Entity Expansion and Improper Input Validation in Kubernetes API server in k8s.io/kubernetes
GO-2022-0782 : Symlink Attack in kubectl cp in k8s.io/kubernetes
GO-2022-0885 : Improper Authentication in Kubernetes in k8s.io/kubernetes
GO-2022-0890 : Server Side Request Forgery (SSRF) in Kubernetes in k8s.io/kubernetes
GO-2022-0907 : Access Restriction Bypass in kube-apiserver in k8s.io/kubernetes
GO-2022-0910 : Files or Directories Accessible to External Parties in kubernetes in k8s.io/kubernetes
GO-2022-0983 : ANSI escape characters not filtered in kubectl in k8s.io/kubernetes
GO-2023-1864 : Kubelet vulnerable to bypass of seccomp profile enforcement in k8s.io/kubernetes
GO-2023-1891 : Vulnerable to policy bypass in kube-apiserver in k8s.io/kubernetes
GO-2023-1892 : Kubernetes mountable secrets policy bypass in k8s.io/kubernetes
GO-2023-1946 : Kubernetes DoS Vulnerability in k8s.io/kubernetes
GO-2023-1977 : Kubernetes can trigger deletion of arbitrary files from the nodes where containers are running in k8s.io/kubernetes
GO-2023-2159 : Kube-proxy may unintentionally forward traffic in k8s.io/kubernetes
GO-2023-2341 : Kubernetes Improper Input Validation vulnerability in k8s.io/kubernetes
GO-2024-2748 : Privilege Escalation in Kubernetes in k8s.io/apimachinery
GO-2024-2753 : Denial of service in Kubernetes in k8s.io/kubernetes
GO-2024-2754 : Sensitive Information leak for users of Ceph RBD via Log File in k8s.io/kubernetes
GO-2024-2755 : Sensitive Information leak for VSphere users via Log File in k8s.io/kubernetes
GO-2024-2994 : Kubernetes sets incorrect permissions on Windows containers logs in k8s.io/kubernetes
GO-2024-3277 : Kubernetes Nil pointer dereference in KCM after v1 HPA patch request in k8s.io/kubernetes
GO-2025-3521 : Kubernetes GitRepo Volume Inadvertent Local Repository Access in k8s.io/kubernetes
GO-2025-3522 : Kubernetes allows Command Injection affecting Windows nodes via nodes/*/logs/query API in k8s.io/kubernetes
GO-2025-3547 : Kubernetes kube-apiserver Vulnerable to Race Condition in k8s.io/kubernetes
GO-2025-3915 : Kubernetes Nodes can delete themselves by adding an OwnerReference in k8s.io/kubernetes
GO-2025-4240 : Half-blind Server Side Request Forgery in kube-controller-manager through in-tree Portworx StorageClass in k8s.io/kubernetes
Discover Packages
k8s.io/kubernetes
pkg
registry
replicaset
package
Version:
v1.5.0-alpha.0....-af3050d
Opens a new window with list of versions in this module.
Published: Sep 16, 2016
License: Apache-2.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package replicaset provides Registry interface and it's RESTStorage
implementation for storing ReplicaSet api objects.
Strategy is the default logic that applies when creating and updating ReplicaSet objects.
MatchReplicaSet is the filter used by the generic etcd backend to route
watch events from etcd to clients of the apiserver only interested in specific
labels/fields.
ReplicaSetToSelectableFields returns a field set that represents the object.
type Registry interface {
ListReplicaSets(ctx api .Context , options *api .ListOptions ) (*extensions .ReplicaSetList , error )
WatchReplicaSets(ctx api .Context , options *api .ListOptions ) (watch .Interface , error )
GetReplicaSet(ctx api .Context , replicaSetID string ) (*extensions .ReplicaSet , error )
CreateReplicaSet(ctx api .Context , replicaSet *extensions .ReplicaSet ) (*extensions .ReplicaSet , error )
UpdateReplicaSet(ctx api .Context , replicaSet *extensions .ReplicaSet ) (*extensions .ReplicaSet , error )
DeleteReplicaSet(ctx api .Context , replicaSetID string ) error
}
Registry is an interface for things that know how to store ReplicaSets.
NewRegistry returns a new Registry interface for the given Storage. Any mismatched
types will panic.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.