package nodeunschedulable
import "k8s.io/kubernetes/pkg/scheduler/framework/plugins/nodeunschedulable"
Index ¶
- Constants
- func New(_ context.Context, _ runtime.Object, _ fwk.Handle, fts feature.Features) (fwk.Plugin, error)
- type NodeUnschedulable
- func (pl *NodeUnschedulable) EventsToRegister(_ context.Context) ([]fwk.ClusterEventWithHint, error)
- func (pl *NodeUnschedulable) Filter(ctx context.Context, _ fwk.CycleState, pod *v1.Pod, nodeInfo fwk.NodeInfo) *fwk.Status
- func (pl *NodeUnschedulable) Name() string
- func (pl *NodeUnschedulable) SignPod(ctx context.Context, pod *v1.Pod) ([]fwk.SignFragment, *fwk.Status)
Constants ¶
const ( // ErrReasonUnknownCondition is used for NodeUnknownCondition predicate error. ErrReasonUnknownCondition = "node(s) had unknown conditions" // ErrReasonUnschedulable is used for NodeUnschedulable predicate error. ErrReasonUnschedulable = "node(s) were unschedulable" )
const Name = names.NodeUnschedulable
Name is the name of the plugin used in the plugin registry and configurations.
Functions ¶
func New ¶
func New(_ context.Context, _ runtime.Object, _ fwk.Handle, fts feature.Features) (fwk.Plugin, error)
New initializes a new plugin and returns it.
Types ¶
type NodeUnschedulable ¶
type NodeUnschedulable struct {
// contains filtered or unexported fields
}
NodeUnschedulable plugin filters nodes that set node.Spec.Unschedulable=true unless the pod tolerates {key=node.kubernetes.io/unschedulable, effect:NoSchedule} taint.
func (*NodeUnschedulable) EventsToRegister ¶
func (pl *NodeUnschedulable) EventsToRegister(_ context.Context) ([]fwk.ClusterEventWithHint, error)
EventsToRegister returns the possible events that may make a Pod failed by this plugin schedulable.
func (*NodeUnschedulable) Filter ¶
func (pl *NodeUnschedulable) Filter(ctx context.Context, _ fwk.CycleState, pod *v1.Pod, nodeInfo fwk.NodeInfo) *fwk.Status
Filter invoked at the filter extension point.
func (*NodeUnschedulable) Name ¶
func (pl *NodeUnschedulable) Name() string
Name returns name of the plugin. It is used in logs, etc.
func (*NodeUnschedulable) SignPod ¶
func (pl *NodeUnschedulable) SignPod(ctx context.Context, pod *v1.Pod) ([]fwk.SignFragment, *fwk.Status)
Feasibility and scoring based on the pod's tolerations.
Source Files ¶
node_unschedulable.go
- Version
- v1.35.1 (latest)
- Published
- Feb 10, 2026
- Platform
- linux/amd64
- Imports
- 11 packages
- Last checked
- 2 months ago –
Tools for package owners.