Affected by GO-2022-0703
and 23 other vulnerabilities
GO-2022-0703 : XML Entity Expansion and Improper Input Validation in Kubernetes API server in k8s.io/kubernetes
GO-2022-0782 : Symlink Attack in kubectl cp in k8s.io/kubernetes
GO-2022-0885 : Improper Authentication in Kubernetes in k8s.io/kubernetes
GO-2022-0890 : Server Side Request Forgery (SSRF) in Kubernetes in k8s.io/kubernetes
GO-2022-0907 : Access Restriction Bypass in kube-apiserver in k8s.io/kubernetes
GO-2022-0910 : Files or Directories Accessible to External Parties in kubernetes in k8s.io/kubernetes
GO-2022-0983 : ANSI escape characters not filtered in kubectl in k8s.io/kubernetes
GO-2023-1864 : Kubelet vulnerable to bypass of seccomp profile enforcement in k8s.io/kubernetes
GO-2023-1891 : Vulnerable to policy bypass in kube-apiserver in k8s.io/kubernetes
GO-2023-1892 : Kubernetes mountable secrets policy bypass in k8s.io/kubernetes
GO-2023-1946 : Kubernetes DoS Vulnerability in k8s.io/kubernetes
GO-2023-2159 : Kube-proxy may unintentionally forward traffic in k8s.io/kubernetes
GO-2023-2341 : Kubernetes Improper Input Validation vulnerability in k8s.io/kubernetes
GO-2024-2748 : Privilege Escalation in Kubernetes in k8s.io/apimachinery
GO-2024-2753 : Denial of service in Kubernetes in k8s.io/kubernetes
GO-2024-2754 : Sensitive Information leak for users of Ceph RBD via Log File in k8s.io/kubernetes
GO-2024-2755 : Sensitive Information leak for VSphere users via Log File in k8s.io/kubernetes
GO-2024-2994 : Kubernetes sets incorrect permissions on Windows containers logs in k8s.io/kubernetes
GO-2024-3277 : Kubernetes Nil pointer dereference in KCM after v1 HPA patch request in k8s.io/kubernetes
GO-2025-3521 : Kubernetes GitRepo Volume Inadvertent Local Repository Access in k8s.io/kubernetes
GO-2025-3522 : Kubernetes allows Command Injection affecting Windows nodes via nodes/*/logs/query API in k8s.io/kubernetes
GO-2025-3547 : Kubernetes kube-apiserver Vulnerable to Race Condition in k8s.io/kubernetes
GO-2025-3915 : Kubernetes Nodes can delete themselves by adding an OwnerReference in k8s.io/kubernetes
GO-2025-4240 : Half-blind Server Side Request Forgery in kube-controller-manager through in-tree Portworx StorageClass in k8s.io/kubernetes
Discover Packages
k8s.io/kubernetes
pkg
util
io
package
Version:
v1.10.0-alpha.1...-99d3e21
Opens a new window with list of versions in this module.
Published: Dec 27, 2017
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
ConsistentRead repeatedly reads a file until it gets the same content twice.
This is useful when reading files in /proc that are larger than page size
and kernel may modify them between individual read() syscalls.
type NsenterWriter struct{}
NsenterWriter is implementation of Writer interface that allows writing data
to file using nsenter command.
If a program (e.g. kubelet) runs in a container it may want to write data to
a mounted device. Since in Docker, mount propagation mode is set to private,
it will not see the mounted device in its own namespace. To work around this
limitation one has to first enter hosts namespace (by using 'nsenter') and
only then write data.
WriteFile calls 'nsenter cat - > <the file>' and 'nsenter chmod' to create a
file on the host.
type StdWriter struct {
}
StdWriter implements Writer interface and uses standard libraries
for writing data to files.
WriteFile directly calls ioutil.WriteFile.
Writer is an interface which allows to write data to a file.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.